@@ -14,6 +14,9 @@ class JobOffer(Model):
     author = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='jobOffers', on_delete=models.SET_NULL, null=True, blank=True)
     title = models.CharField(max_length=255, blank=True, null=True)
     description = models.TextField(blank=True, null=True)
+    duration = models.CharField(max_length=255, blank=True, null=True)
+    budget = models.CharField(max_length=255, blank=True, null=True)
+    earnBusinessProviding = models.BooleanField(default=False)
     skills = models.ManyToManyField(Skill, blank=True)
     creationDate = models.DateTimeField(auto_now_add=True)
     closingDate = models.DateField(null=True)
